@@ -1,6 +1,7 @@
 from django.db import models
 from django.db.models import Max
 from django.db.models.query import QuerySet
+from django.utils import timezone
 from django.utils.text import slugify
 
 from francedata.services.django_admin import TimeStampModel
@@ -41,6 +42,10 @@ class DataYear(TimeStampModel):
     class Meta:
         verbose_name = "millésime"
 
+    @classmethod
+    def get_latest(cls):
+        return cls.objects.order_by("-year")[0]
+
 
 class DataSource(TimeStampModel):
     """
@@ -48,14 +53,29 @@ class DataSource(TimeStampModel):
     """
 
     title = models.CharField("titre", max_length=255)
-    url = models.CharField("URL", max_length=255)
+    url = models.CharField("URL", max_length=255, null=True, blank=True)
     year = models.ForeignKey(
         "DataYear", on_delete=models.RESTRICT, verbose_name="millésime"
     )
+    public_label = models.CharField(
+        "libellé public", max_length=1000, null=True, blank=True
+    )
+    is_imported = models.BooleanField("import effectué", default=False)
+    imported_at = models.DateTimeField("date d’import", null=True, blank=True)
 
     def __str__(self):
         return f"{self.title} ({self.year})"
 
+    def get_public_label(self) -> str:
+        if self.public_label:
+            return self.public_label
+        else:
+            return self.__str__()
+
+    def mark_imported(self) -> None:
+        self.is_imported = True
+        self.imported_at = timezone.now()
+
     class Meta:
         verbose_name = "source"
         unique_together = (("title", "url", "year"),)
@@ -248,6 +268,33 @@ class Commune(CollectivityModel):
     def create_slug(self):
         self.slug = slugify(f"{self.name}-{self.insee}")
 
+    @classmethod
+    def get_prefectures(cls) -> QuerySet:
+        """
+        Returns a queryset with all préfectures
+        """
+        return cls.objects.filter(
+            insee__in=DepartementData.objects.filter(datacode="seat_insee").values_list(
+                "value", flat=True
+            )
+        )
+
+    @classmethod
+    def get_main_cities_by_population(cls, population: int = 50000) -> QuerySet:
+        """
+        Returns a queryset with cities over a set population (default: 50 000)
+        """
+        return cls.objects.filter(population__gt=population)
+
+    @classmethod
+    def get_main_cities(cls) -> QuerySet:
+        """
+        Returns a queryset that combines préfectures and most populated cities
+        """
+        prefectures = cls.get_prefectures()
+        most_populated = cls.get_main_cities_by_population()
+        return prefectures | most_populated
+
 
 # France collectivities data models
 class CollectivityDataModel(TimeStampModel):
